==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_fields/STEPCONDITIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for STEPCONDITIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="STEPCONDITIONID_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}APPROVALSTEPPK"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}COLUMN" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "STEPCONDITIONID_Type", propOrder = {
    "approvalsteppk",
    "column"
})
public class STEPCONDITIONID_Type {

    @XmlElement(name = "APPROVALSTEPPK", required = true)
    protected STANDARDENTITYID_Type approvalsteppk;
    @XmlElement(name = "COLUMN")
    protected String column;

    /**
     * Gets the value of the approvalsteppk property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getAPPROVALSTEPPK() {
        return approvalsteppk;
    }

    /**
     * Sets the value of the approvalsteppk property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setAPPROVALSTEPPK(STANDARDENTITYID_Type value) {
        this.approvalsteppk = value;
    }

    /**
     * Gets the value of the column property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOLUMN() {
        return column;
    }

    /**
     * Sets the value of the column property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOLUMN(String value) {
        this.column = value;
    }

}

==> eam-wshub-proxyclient-12.1-3-sources.jar: net/datastream/schemas/mp_fields/STEPCONDITIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for STEPCONDITIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="STEPCONDITIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APPROVALSTEPPK"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COLUMN" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "STEPCONDITIONID_Type", propOrder = {
    "approvalsteppk",
    "column"
})
public class STEPCONDITIONID_Type {

    @XmlElement(name = "APPROVALSTEPPK", required = true)
    protected STANDARDENTITYID_Type approvalsteppk;
    @XmlElement(name = "COLUMN")
    protected String column;

    /**
     * Gets the value of the approvalsteppk property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getAPPROVALSTEPPK() {
        return approvalsteppk;
    }

    /**
     * Sets the value of the approvalsteppk property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setAPPROVALSTEPPK(STANDARDENTITYID_Type value) {
        this.approvalsteppk = value;
    }

    /**
     * Gets the value of the column property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOLUMN() {
        return column;
    }

    /**
     * Sets the value of the column property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOLUMN(String value) {
        this.column = value;
    }

}
